@@ -79,8 +79,13 @@ macro_rules! def_package {
             }
         }
 
+        impl Default for $package {
+            fn default() -> Self {
+                Self::new()
+            }
+        }
+
         impl $package {
-            #[allow(dead_code)]
             pub fn new() -> Self {
                 let mut module = $root::Module::new();
                 <Self as $root::packages::Package>::init(&mut module);
